#! /bin/sh
#+
#
# .. program:: classes_principales.sh
#
# .. _classes_principales.sh:
#
# ======================
# classes_principales.sh
# ======================
#
# SYNOPSIS
# ========
#
# ::
#
#  $ classes_principales.sh -a application
#
# DESCRIPTION
# ===========
#
# .. option:: -a application
#                matlab or octave
#
# - Run :func:`classes_principales` with ``octave`` or
#   ``matlab`` using :option:`-a` option,
#
# - Compile :file:`classes_principales.tex` using ``pdflatex``.
#
# At the end of execution, PDF is written in
# :file:`${PROJECT_OD}/classes_principales.pdf`
#
# Log file is written on
# :file:`${PROJECT_LOG}/classes_principales.log.{YYYYMMDDTHHMMSSZ}`.
#
# EXAMPLES
# ========
#
# To run :func:`classes_principales` with matlab::
#
#   $ classes_principales.sh -a matlab
#
# To run :func:`classes_principales` with octave::
#
#   $ classes_principales.sh -a octave
#
# SEE ALSO
# ========
#
# :ref:`data_lai`
#
# :ref:`varamma_profile.sh`
#
# :func:`classes_principales`
#
# :file:`classes_principales.tex`
# :file:`classes_principales.bib`
#
# TODO
# ====
#
# use pdflatex with -halt-on-error option, not yet done because of
# bad hadling of floating figures (see classes_principales.tex)
#
# check existence of classes_principales.tex and classes_principales.bib
#
# if matlab running, test if licence ok
#
# biblio not yet well processed
#
# move this tool in a publication part
#
# EVOLUTIONS
# ==========
#
# $Id$
#
# $URL$
#
# - fplod 20110923T074512Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * suppress figure on screen
#     nb : --nodisplay opriton of matlab has been remmove
#     because introduce a nounderstanded crash !!
#   * test status of matlab/octave script execution
#
# - fplod 20110916T133232Z cratos (Linux)
#
#   * allowed concurent session
#
# - fplod 20110909T165744Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * add bibtex
#
# - fplod 20110909T132855Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * creation
#
#-
system=$(uname)
case "${system}" in
AIX|IRIX64)
  echo " www : no specific posix checking"
;;
*)
  set -o posix
;;
esac
unset system
#
set -u
#
LANG=POSIX
#
command=$(basename ${0})
log_date=$(date -u +"%Y%m%dT%H%M%SZ")
#
usage=" Usage : ${command} -a application"
#
hostname=$(hostname)
#
case "${system}" in
Darwin)
 timecmd=/usr/bin/time
;;
*)
 timecmd=time
;;
esac
#
# default
application=octave
#
minargcount=2
if [ ${#} -lt ${minargcount} ]
then
  echo "eee : not enought arguments"
  echo "${usage}"
  exit 1
fi
#
while [ ${#} -gt 0 ]
do
 case ${1} in
 -a)
  application=${2}
  shift
 ;;
 *) # anything else
  echo "eee : ${usage}"
  exit 1
 ;;
 esac
 shift # next flag
done
#
log=${PROJECT_LOG}/$(basename ${0} .sh).log.${log_date}
echo "[Context]" 1>> ${log}
echo "command = ${command}" 1>> ${log}
echo "runtime = ${log_date}" 1>> ${log}
echo "hostname = $(hostname)" 1>> ${log}
echo "" 1>> ${log}
echo "[Parameters]" 1>> ${log}
echo "application = ${application}" 1>> ${log}
echo "" 1>> ${log}
#
# test if application available
tool=${application}
type ${tool} 1> /dev/null 2>&1
status=${?}
if [ ${status} -ne 0 ]
then
 echo " eee : ${tool} not found"
 exit 1
fi
unset status
#
script=${PROJECT_LOG}/script_${log_date}.m
#
{
echo "close all"
echo "clear all"
echo "varamma_startup"
echo "more off"
echo "set (0, 'defaultfigurevisible', 'off');"
echo "result=classes_principales()"
echo "quit"
} > ${script}
#
case ${application} in
matlab)
 ${timecmd} matlab -nojvm -nosplash <  ${script} 1>> ${log} 2>&1
 status=${?}
;;
octave)
 ${timecmd} octave --silent ${script} 1>> ${log} 2>&1
 status=${?}
;;
esac
#
if [ ${status} -ne 0 ]
then
   echo "eee : ${application} script failed" 1>> ${log} 2>&1
   exit 1
fi
# remove temporary latex files
rm ${PROJECT_OD}/classes_principales.bbl \
   ${PROJECT_OD}/classes_principales.blg \
   ${PROJECT_OD}/classes_principales.log \
   ${PROJECT_OD}/classes_principales.out \
   ${PROJECT_OD}/classes_principales.aux \
   2> /dev/null

pdflatex \
   -output-directory ${PROJECT_OD} \
   ${PROJECT}/src/classes_principales.tex 1>> ${log} 2>&1
bibtex ${PROJECT_OD}/classes_principales 1>> ${log} 2>&1
pdflatex -output-directory ${PROJECT_OD} \
   ${PROJECT}/src/classes_principales.tex 1>> ${log} 2>&1
pdflatex -output-directory ${PROJECT_OD} \
   ${PROJECT}/src/classes_principales.tex 1>> ${log} 2>&1
#
rm ${script} 2> /dev/null
#
# remove temporary latex files
rm ${PROJECT_OD}/classes_principales.bbl \
   ${PROJECT_OD}/classes_principales.blg \
   ${PROJECT_OD}/classes_principales.log \
   ${PROJECT_OD}/classes_principales.out \
   ${PROJECT_OD}/classes_principales.aux \
   2> /dev/null
#
unset log_date
#
exit
