#! /bin/sh
#
#+
#
# .. program:: extract_zone_nc.sh
#
# .. _extract_zone_nc.sh:
#
# ==================
# extract_zone_nc.sh
# ==================
#
# -------------------------------------------------
# Extract zone from NetCDF MSG, AMSU or EPSAT files
# -------------------------------------------------
#
# SYNOPSIS
# ========
#
# ::
#
#  $ extract_zone_nc.sh
#
# DESCRIPTION
# ===========
#
# Extract zone from NetCDF MSG, AMSU or EPSAT files.
#
# If **datasettype** is set to ``msg_netcdf_15min``, input files are 
# :file:`${PROJECT_ID}/MSG/{yyyy}/{mm}/{dd}/{yyyymmddmmmn}"_msg-{product}_map_15min.nc`
#
# TODO
# ====
#
# log file
#
# boxes and time parametrization
#
# see also ?
#
# coding rules
#
# add parameters
#
# EVOLUTIONS
# ==========
#
# - fplod 20110601T133702Z aedon.locean-ipsl.upmc.fr
#
#   * add pseudo parameter datasettype
#
# - fplod 20110601T105538Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * remove -type f from find command to avoid trouble with symbolic links
#   * add a test ncks return status
#
# - pinsard 2011-06-01T09:11:35Z loholt1.ipsl.polytechnique.fr (Linux)
#
#   * add test if a least one file found
#
# - fplod 20110531T101614Z cratos.locean-ipsl.upmc.fr (Linux)
#
#   * corrdection of netCDF variable names
#   * path of nco tools on locean* is /opt/bin cf. ticket 
#     https://zethos/glpi/index.php?redirect=tracking_1974
#   * correction on outdir
#
# - fplod 20110531T091906Z cratos.locean-ipsl.upmc.fr (Linux)
#
#   * some consolidation
#
# - lelod 20110530
#
#   * some differences when using on macbook (add quotes to directories and files)
#
# - lelod and fplod 20110706
#
#   * make it work both on cratos and on skylla
#   * add path for extracted data consistent with VARAMMA rules
#
#-
set -u
#amsubch5-noaa15_20060731-184200_afratl_Nadir.nc ou msg-tb108_2006-07-02_15min.nc ou 
#surf-rr_epsat-sg_multi-sat_010d_30min_20060809_v3.1-02c.nc
yyyy=2006
mm=07
lonmin=-20.
lonmax=0.
latmin=0.
latmax=20.
# uncomment the following line to process 15mn NetCDF files
#datasettype="msg_netcdf_15min"
# uncomment the following line to process 3B40 NetCDF files
datasettype="EPSAT"
#
# uncomment this line if you want to work with the official data tree
indir_base=${PROJECT_ID}
#MSG/${yyyy}/${mm}/
#
# define argument of command find = f(datasettype)
case "${datasettype}" in
    msg_netcdf_15min)
       product="tb108"
       find_name=msg-${product}_${yyyy}-${mm}-??_15min.nc
       # uncomment this line if you want to work with the official data tree
       find_dir=${indir_base}MSG/${yyyy}/${mm}/
       # do not forget to comment the unofficial one
       #find_dir="/volumes/Lacie/MSG/2006/07"
       outdir=${PROJECT_ID}MSG/extracted/${yyyy}/${mm}
       latvar=LATITUDE
       lonvar=LONGITUDE
    ;;
    AMSU)
	
       find_name="amsu$product-noaa*_afratl_Nadir.nc"
       # uncomment this line if you want to work with the official data tree
       find_dir=${indir_base}AMSU/${yyyy}/${mm}/
       # do not forget to comment the unofficial one
       #find_dir="/volumes/Lacie/AMSU/2006/08"
       outdir="${PROJECT_ID}AMSU"
       latvar=lat
       lonvar=lon
    ;;
    EPSAT)
       find_name=surf-rr_epsat-sg_multi-sat_010d_30min_${yyyy}${mm}??_v3.1-02c.nc
       # uncomment this line if you want to work with the official data tree
       find_dir=${indir_base}EPSAT/${yyyy}/${mm}/
       # do not forget to comment the unofficial one
       #find_dir="/volumes/Lacie/EPSAT-SG"
       outdir="${PROJECT_ID}EPSAT/extracted/${yyyy}/${mm}"
       latvar=lat
       lonvar=lon

esac
#
# find files
lesfiles=$(find ${find_dir} -name "${find_name}")
#
# 
if [ "${lesfiles}" = "" ]
then 
   echo "iii : no files ${find_name} found under ${find_dir}"
   exit 0
fi

mkdir -p ${outdir}

for ifile in ${lesfiles} 
do
  filename=$(basename $ifile)
  newfile="extracted-${filename}"
#  newfile2="extracted2-${filename}"
  echo "Extraction depuis ${ifile}"
  ncks -O -h -d ${latvar},${latmin},${latmax} -d ${lonvar},${lonmin},${lonmax} ${ifile} ${outdir}/${newfile}
  status=${?}
  if [ ${status} -ne 0 ]
  then
      echo "eee : pb with ncks on ${ifile}"
      ncdump -h ${ifile}
      exit 1
  else
      echo "iii : adding ${outdir}/${newfile}"
  fi
# ncap2 -O -h -s '*nblon=$longitude.size;for (*idx=0;idx<nblon;idx++){if (longitude(idx) > 180) longitude(idx)=longitude(idx)-360.;}' ${outdir}/tmp/${newfile} ${outdir}/tmp/${newfile2}
# rm -f ${outdir}/${newfile}
done
