#! /bin/sh
#+
#
#
# .. _is_leap_year.sh:
#
# .. program:: is_leap_year.sh
#
# ===============
# is_leap_year.sh
# ===============
#
# --------------------
# tell if year is leap
# --------------------
#
# SYNOPSIS
# ========
#
# ``is_leap_year.sh [yyyy]``
#
# DESCRIPTION
# ===========
#
# Tell if year is leap by exit status.
#
# If no argument is given, current year will be used.
#
# EXAMPLES
# ========
#
# Is 2000 leap ?::
#
#  $ is_leap_year.sh 2000
#  $ echo ${?}
#  0
#
# Is 2001 leap ?::
#
#  $ is_leap_year.sh 2001
#  $ echo ${?}
#  1
#
# TODO
# ====
#
# .. todo::
#
# unset
#
# EVOLUTIONS
# ==========
#
# $Id$
#
# - fplod 20100318T075424Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#
# - fplod 2008-08-05T13:21:05Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * creation from http://cfaj.freeshell.org/shell/tuesday-tips/#tt-2004-06-08
#
#-
#
LANG=POSIX
#
ily_year=${1:-`date +%Y`}
[ $(( ${ily_year} % 400)) -eq 0 -o \
  \( $(( ${ily_year} % 4)) -eq 0 -a \
  $(( ${ily_year} % 100)) -ne 0 \) ] && {
   exit 0
   } || {
    exit 1
   }
