;+
;
; .. _pixelsize.pro:
;
; =============
; pixelsize.pro
; =============
;
; DESCRIPTION
; ===========
;
; calcul de la taille des taches au sol amsua et amsub
; suivant l'article de [Bennartz:JAOT:2000]_
;
; swath(ab): grand axe de la tache au sol (sens fauchee == swath)
;
; track(ab) : petit axe de la tache au sol (sens trajectoire sat == track)
;
; parametrisation des nb points fauchee:
; 2x15 pour AMSUA, 2x45 pour AMSUB
;
; SEE ALSO
; ========
;
; :ref:`data_amsu`
;
; Called by :ref:`correct_nadir_amsu.pro`
;
; EXAMPLES
; ========
;
; ::
;
;    pixelsize, swatha, swathb, tracka, trackb
;
; TODO
; ====
;
; remplacer le "pro" par "function"
; prevoir trace de controle des tailles de pixel (ellipes)
; tester les dimensionnements
;
; on peut changer le codage en dur des fauchees ou demi-fauchees, mais
; programme adapte a AMSUA et AMSUB, pas MHS (90 points, mais fauchee
; un peu plus large)
;
; ajouter un dessin dans l'exemple
;
; EVOLUTIONS
; ==========
;
; $Id$
;
; $URL$
;
; - fplod 20120417
;
;   * usage of key_performance
;
; - fplod 20111103T112308Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * fix and complete header
;
; - lelod 20111019
;
;   * creation
;
;-
pro pixelsize, swatha,swathb,tracka,trackb
;
@cm_project
@common
s = size(SCOPE_TRACEBACK(/STRUCTURE),/DIMENSION)
routine = (SCOPE_TRACEBACK(/STRUCTURE))[s-1].Routine
;
if key_performance EQ 1 THEN BEGIN
    time1 = SYSTIME(1)
ENDIF
;
alongb=fltarr(45)
alonga=fltarr(15)
pixa=fltarr(15)
pixb=fltarr(45)

;taille pixels dans la fauchee incluant l'elargissement par integration - partant du bord
for n=0,44 do pixb(n)=79.08+2.84*(n+1)-14.78*(n+1)^0.666
for n=0,14 do pixa(n)=230.65+12.39*(n+1)-95.06*(n+1)^0.5

; taille pixel dans le sens de la marche
for n=0,14 do alonga(n)=83.01-7.28*(n+1)+1.28*(n+1)^1.5
for n=0,44 do alongb(n)=28.72-0.9*(n+1)+0.094*(n+1)^1.5

; symetrie pour l'autre demi fauchee
pix_b=fltarr(45)
along_b=fltarr(45)
for i=0,44 do pix_b(i)=pixb(44-i)
for i=0,44 do along_b(i)=alongb(44-i)
pixbtot=[pixb,pix_b]
alongbtot=[alongb,along_b]
pix_a=fltarr(15)
along_a=fltarr(15)
for i=0,14 do pix_a(i)=pixa(14-i)
for i=0,14 do along_a(i)=alongb(14-i)
pixatot=[pixa,pix_a]
alongatot=[alonga,along_a]

swatha=pixatot
swathb=pixbtot
tracka=alongatot
trackb=alongbtot

IF key_performance EQ 1 THEN BEGIN
   msg = report(['ppp : ' + routine + ' : dure totale ' $
               + string(SYSTIME(1)-time1,format='(F12.6)')])
ENDIF

end
