#! /bin/sh
#+
#
# .. program:: presentation_lpao.sh
#
# .. _presentation_lpao.sh:
#
# ====================
# presentation_lpao.sh
# ====================
#
# SYNOPSIS
# ========
#
# ::
#
#  $ presentation_lpao.sh -a application
#
# DESCRIPTION
# ===========
#
# .. option:: -a application
#                matlab or octave 
#
# - Run :func:`presentation_lpao` with `octave`` or
#   ``matlab`` using :option:`-a` option,
#
# - Compile :file:`presentation_lpao.tex` using ``pdflatex``.
#
# At the end of execution, PDF is written in
# :file:`${PROJECT_OD}/presentation_lpao.pdf`
#
# Log file is written on
# :file:`${PROJECT_LOG}/presentation_lpao.log.{YYYYMMDDTHHMMSSZ}`.
#
# EXAMPLES
# ========
#
# To run :func:`presentation_lpao` with matlab::
#
#   $ presentation_lpao.sh -a matlab
#
# To run :func:`presentation_lpao` with octave::
#
#   $ presentation_lpao.sh -a octave
#
# SEE ALSO
# ========
#
# :ref:`data_lai`
#
# :ref:`varamma_profile.sh`
#
# :func:`presentation_lpao`
#
# :file:`presentation_lpao.tex`
#
# TODO
# ====
#
# ++use pdflatex with -halt-on-error option, not yet done because .m and .tex
# associated files not stabilized
#
# check existence of presentation_lpao.tex
#
# if matlab running, test if licence ok
#
# move this tool in a publication part
#
# faire propre sur le pb de dtection de la prsence de matlab/octave
# en fonction des systemes
#
# EVOLUTIONS
# ==========
#
# $Id: presentation_lpao.sh -1   $
#
# $URL$
#
# - fplod/soclod 20111214
#
#   * affreux patch car octave est un alias sur mac
#     et les alias ne sont pas connus dans un shell !!
# - fplod 20110923T074512Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * suppress figure on screen
#     nb : --nodisplay opriton of matlab has been remmove
#     because introduce a nounderstanded crash !!
#   * test status of matlab/octave script execution
#
# - fplod 20110921T131050Z cratos (Linux)
#
#   * creation
#
#-
system=$(uname)
case "${system}" in
AIX|IRIX64)
  echo " www : no specific posix checking"
;;
Darwin)
  octavecmd=/Applications/Octave.app/Contents/Resources/bin/octave
  set -o posix
;;
*)
  set -o posix
;;
esac
#
set -u
#
LANG=POSIX
#
command=$(basename ${0})
log_date=$(date -u +"%Y%m%dT%H%M%SZ")
#
usage=" Usage : ${command} -a application"
#
hostname=$(hostname)
#
case "${system}" in
Darwin)
 timecmd=/usr/bin/time
;;
*)
 timecmd=time
;;
esac
#
# default
application=${octavecmd}
#
minargcount=2
if [ ${#} -lt ${minargcount} ]
then
  echo "eee : not enought arguments"
  echo "${usage}"
  exit 1
fi
#
while [ ${#} -gt 0 ]
do
 case ${1} in
 -a)
  application=${2}
  shift
 ;;
 *) # anything else
  echo "eee : ${usage}"
  exit 1
 ;;
 esac
 shift # next flag
done
#
case ${application} in
octave)
 application=${octavecmd}
;;
esac
log=${PROJECT_LOG}/$(basename ${0} .sh).log.${log_date}
echo "[Context]" 1>> ${log}
echo "command = ${command}" 1>> ${log}
echo "runtime = ${log_date}" 1>> ${log}
echo "hostname = $(hostname)" 1>> ${log}
echo "" 1>> ${log}
echo "[Parameters]" 1>> ${log}
echo "application = ${application}" 1>> ${log}
echo "" 1>> ${log}
#
# test if application available
tool=${application}
type ${tool} 1> /dev/null 2>&1
status=${?}
if [ ${status} -ne 0 ]
then
 echo " eee : ${tool} not found"
 exit 1
fi
unset status
#
script=${PROJECT_LOG}/script_${log_date}.m
{
echo "close all"
echo "clear all"
echo "varamma_startup"
echo "more off"
echo "set (0, 'defaultfigurevisible', 'off');"
echo "result=presentation_lpao()"
echo "quit"
} > ${script}
#
case ${application} in
matlab)
 ${timecmd} matlab -nojvm -nosplash < ${script} 1>> ${log} 2>&1
 status=${?}
;;
${octavecmd})
 ${timecmd} ${octavecmd} --silent ${script} 1>> ${log} 2>&1
 status=${?}
;;
esac
#
if [ ${status} -ne 0 ]
then
   echo "eee : ${application} script failed" 1>> ${log} 2>&1
   exit 1
fi
# remove temporary latex files
rm ${PROJECT_OD}/presentation_lpao.log \
   ${PROJECT_OD}/presentation_lpao.out \
   ${PROJECT_OD}/presentation_lpao.aux \
   2> /dev/null
#
pdflatex \
   -output-directory ${PROJECT_OD} \
   ${PROJECT}/src/presentation_lpao.tex 1>> ${log} 2>&1
#
#++rm ${script} 2> /dev/null
#
# remove temporary latex files
rm ${PROJECT_OD}/presentation_lpao.log \
   ${PROJECT_OD}/presentation_lpao.out \
   ${PROJECT_OD}/presentation_lpao.aux \
   2> /dev/null
#
unset log_date
unset system
#
exit
