;+
;
; .. _project_init.pro:
;
; ==========================================
; project_init.pro -- init SAXO environment
; ==========================================
;
; DESCRIPTION
; ===========
;
; This is the SAXO initialisation file.
;
; It ++::
;
;   idl -startupfile project_init.pro
;
; or::
;
;   idl -IDL_STARTUP project_init.pro
;
; or::
;
;   idl
;   @project_init
;
;
; SEE ALSO
; ========
;
; :ref:`varamma_profile.sh`
;
; :ref:`cm_project.pro`
;
; TODO
; ====
;
; learn to write IF .. ELSE in a @file
;
; improve SAXO behaviour in batch mode using fstat and interactive structure field
; to avoid ``Error occurred at: LOADCT`` and ``% FILE_TEST: String expression required in this context: MYUNIQUETMPDIR``
;
; EVOLUTIONS
; ==========
;
; $Id$
;
; $URL$
;
; - fplod 20120420
;
;   * move init statement of key_performance and min and max time
;     because not processed in batch mode 
;
; - fplod 20120419
;  
;   * add min and max time
;
; - fplod 20120417
;
;   * define default value of key_performance
;
; - fplod 20110422T153436Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * fix pb when IDL_STARTUP is set to project_init.pro
;     (cm_project.pro was not found)
;
; - fplod 20110422T132143Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * creation
;
;-
; 
; SAXO environment
saxo_dir_env=GETENV('SAXO_DIR')
;
; project environment #1
project_env_temp=GETENV('PROJECT')
project_id_env_temp=GETENV('PROJECT_ID')
project_od_env_temp=GETENV('PROJECT_OD')
;
; path definition
!path = expand_path('+' + project_env_temp + '/src') $
      + path_sep(/search_path) + expand_path('+' + saxo_dir_env) $
      + path_sep(/search_path) + expand_path('+' + !dir)
;
; project environment #2
@cm_project
project_env=project_env_temp
project_id_env=project_id_env_temp
project_od_env=project_od_env_temp
;
; compatibility with the old version
;
keep_compatibility, 0
;
; define all the commons
;
@cm_4cal
@cm_4data
@cm_4mesh
@cm_4data
@cm_4ps
@cm_general
;
key_performance = 0
;
yyyymmddb_min=20000101L
yyyymmdde_max=20121231L
;
; define default directories
;
homedir = isadirectory(project_env + '/src/', title = 'Select the default HOME directory')
iodir = isadirectory(project_id_env, title = 'Select the default IO directory')
psdir = isadirectory(project_od_env, title = 'Select the default postscripts directory')
imagedir = isadirectory(project_od_env, title = 'Select the default images directory')
animdir = isadirectory(project_od_env, title = 'Select the default animations directory')
;
; define printer parameters
;
printer_human_names = ''
printer_machine_names = ''
print_command = ''
;
; colors ...
;
device, decomposed = 0
device, retain = 2
lct, 39
;
; postscript parameters ...
;
key_portrait = 0
page_size = [20.9903, 29.7039]
windowsize_scale = 1.00000
archive_ps = 0
;
;========================================================
; end of the part that should be modified by the users...
;========================================================
;
; if needed, keep compatibility with the old version
;
@updateold
;
