function[mat_3D,lat ,lon,jours,niveau]=readERA(file, z_deb, z_fin,nom_var,chemin)

% routine de lecture d un fichier de donnees ERA40 au format netcdf sur
%  la zone definie par les points z_deb zfin de forme [lat lon time level]

%+
%
% .. _readERA.m:
%
% =========
% readERA.m
% =========
%
% DESCRITPTION
% ============
%
% routine de lecture d un fichier de donnees ERA40 au format netcdf sur
%  la zone definie par les points z_deb zfin de forme [lat lon time level]
%
% EVOLUTIONS
% ==========
%
% $Id: readERA.m 325 2011-08-04 15:30:01Z pinsard $
%
% $URL$
%
% - fplod 20110124T154122Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add rst header
%
%-
usage='[mat_3D,lat ,lon,jours,niveau]=readERA(file, z_deb, z_fin,nom_var,chemin)';

if(nargin<2)
z_deb=[ -30 -60 datenum(1957,1,1) 500]  
end
if(nargin<3)
z_fin=[ 45 50 datenum(2020,1,1) 500]   
end
if(nargin<4)
  [groupe,reste]=strtok(file,'.');
  [nom_var,reste]=strtok(reste,'.'); 
end
if(nargin<5)
     chemin='/homedata/eymard/OPERA_Trop/';
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
if(chemin(end)~='/')
chemin=[chemin,'/'];
end

file=[chemin,file];

nc=netcdf(file,'nowrite');
longitude=nc{'lon'}(:);
latitude=nc{'lat'}(:);
jours=nc{'time'}(:);
niveau=nc{'level'}(:);

jo=find(jours~=0);
jours=jours(jo)/24+datenum(1957,01,01); % En jours juliens
jo=find(jours>z_deb(3) & jours<z_fin(3));
jours=jours(jo);


lom=find(longitude-360>z_deb(2) & longitude-360<z_fin(2));
lop=find(longitude>z_deb(2) & longitude<z_fin(2));
lon=cat(1,longitude(lom)-360,longitude(lop));


%[lat,la]=sort(latitude,'ascend');
la=find(latitude>z_deb(1) & latitude<z_fin(1));
lat=sort(latitude(la),'ascend');

ni=find(niveau>=z_deb(4) & niveau<=z_fin(4));
niveau=niveau(ni);
 
variable_p=[];
variable_m=[];
 
if(isempty(niveau)) %variable 3D 
%extraction de la variable pour les longitudes positives et negatives
if(~isempty(lop))
  variable_p=nc{nom_var}(jo,la,lop);
end
if(~isempty(lom))
  variable_m=nc{nom_var}(jo,la,lom);
end
variable=cat(3,variable_m,variable_p); 
%Remise des latitudes dans le sens ascendant
variable=variable(:,end:-1:1,:);
%% mat_3D est la matrice (lat,lon, jours) de sortie 
mat_3D=permute(variable,[2 3 1]);  
  
else %Variable 4D dont on moyenne la dimension "niveau"
%extraction de la variable pour les longitudes positives et negatives
if(~isempty(lop)) 
  variable_p=nc{nom_var}(jo,ni,la,lop);
end
if(~isempty(lom))
 variable_m=nc{nom_var}(jo,ni,la,lom);
end
variable=cat(4,variable_m,variable_p);
%Remise des latitudes dans le sens ascendant
variable=variable(:,:,end:-1:1,:);

%% mat_3D est la matrice (lat,lon,jours) de sortie 
mat_3D=permute(variable,[3 4 1 2]);
mat_3D=squeeze(mean(mat_3D,4));
end

