function [result] = serietemp(data, dimtemp, formattemps, nbtickmax, nomvar, infocompl)

%SERIETEMP est une fonction permettant de tracer une serie temporelle.

%
%+
%
% ============
% serietemp.m
% ============
%
% .. function:: serietemp(data, dimtemp, formattemps, nbtickmax, nomvar, infocompl)
%
% DESCRIPTION
% ===========
%
% - Donnees d'entrees :
%
%   * data : Vecteur colonne de donnees dont la seule dimension est
%     temporelle.
%   * dimtemp : Dimension temporelle de la matrice de donnees 'data' en
%     jour julien.
%   * formattemps (caracteres) : Format d'affichage du temps sur l'abscisse
%     de la serie temporelle ('HH:MM' pour avoir l'heure, 'mmm dd' pour le
%     mois et le jour par exemple, etc. voir l'aide pour datestr).
%   * nbtickmax : Nombre maximum de 'tick' sur l'axe des abscisses (axe
%     temporel).
%   * nomvar (en caracteres) : Nom de la variable dont on trace la
%     distribution (Pour le titre et l'axe des abscisses).
%   * infocompl (en caracteres, facultatif) : Informations complementaires 
%     sur les donnees pour le titre. (Sur la date par exemple 'du 26/07 au
%     ...' par exemple).
%
% Cette fonction permet de tracer une serie temporelle.
%
% EXAMPLES
% ========
%
% Voir la 'demo'.
%
% SEE ALSO
% ========
%
% TODO
% ====
%
% in demo replace random to make comparison between matlab/octave and machine
% easier
%
% improve optional arguments 
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL: svn+ssh://pinsard@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/serietemp.m $
%
% - fplod 20110804T124821Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add result
%
% - jaclod 2011-07-27
%
%   * Revision de la documentation et des commentaires.
%   * Modification de la demonstration.
%
% - jaclod 2011-07-25
%
%   * Creation.
%
%-

result=-1;

usage='[result] = serietemp(data, dimtemp, formattemps, nbtickmax, nomvar, infocompl)';
%
if nargin < nargin(mfilename) - 1
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage);
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
% Tracage de la serie temporelle.
plot(dimtemp,data);

% Ajout de titre, variant selon le nombre d'arguments d'entrees.
if nargin == 6;
    title(['Serie temporelle des ' nomvar ' ' infocompl])
else
    title(['Serie temporelle des ' nomvar])
end

% Ajout des noms des axes.
xlabel('Temps')
ylabel(nomvar)

% Modification des bornes des axes.
axis([min(dimtemp) max(dimtemp) fix(min(data(:))) ceil(max(data(:)))]);

% Nombre de pas de temps.
nbtimestep = size(data,1);

% On cherche le pas d'affichage des pas de temps pour ne pas depasser la
% limite autorisee (on prend l'arrondi superieur avec la fonction 'ceil').
tickstep = ceil(nbtimestep / nbtickmax);

% On garde les numero dans temps a afficher.
numtime = 1 : tickstep : nbtimestep;

% On enregistre les futures 'ticklabel' sous forme de caracteres.
time = datestr(dimtemp(numtime),formattemps);

% Modification de l'affichage sur l'axe des abscisses.
set(gca,'xtick',dimtemp(numtime));
set(gca,'xticklabel',time);

result=0;

end

%!demo
%! clear all
%! close all
%! result = serietemp(rand(25,1), datenum(2011,07,25):datenum(2011,07,25)+24, 'mmm dd',7, 'valeurs aleatoires quotidiennes', 'sur 25 jours a partir du 25 juillet 2011');
