function [lon_value, lat_value, altitude_value, code_value, station_value, region_value]=simul_station(index_simulation)

%SIMUL_PRECIP fill station pluviometer associated arrays lat, lon, alt, name
%with hard coded data

%
%+
%
% ===============
% simul_station.m
% ===============
%
% .. function:: simul_station(index_simulation)
%
% DESCRIPTION
% ===========
%
%    :param index_simulation: 1
%    :type index_simulation: uint8
%    :raise index_simulation: required
%
% Charge en mmoire un tableau 2D simul **station** de prcipitation dans :
%
% Simulation #1
%   10 stations named ``station``\ xx
%
% Simulation #2
%   2 stations barkedji+linguere
%
% Les longitudes sont stockes dans le tableau **lon_value**.
%
% Les latitudes sont stockes dans le tableau **lat_value**.
%
% Les altitudes sont stockes dans le tableau **altitude_value**.
%
% Les noms sont stockes dans le tableau **station_value**.
%
% Les regions sont stockes dans le tableau **region_value**.
%
% EXAMPLES
% ========
%
% From scratch to create 10 stations pluviometer associated arrays:
%
% see demo 1
%
% To write these arrays in
% file:`${PROJECT_OD}/PRECIP/station_write_station.csv`::
%
%  octave> result=write_station(lon_value, lat_value, altitude_value, code_value, station_value, region_value);
%
% To plot the station pluviometer on a map grid::
%
%  octave> lonmin=-20;
%  octave> lonmax=-10;
%  octave> latmin=10;
%  octave> latmax=20;
%  octave> result=plot_station(lonmin, lonmax, latmin, latmax, lon_value, lat_value, code_value, station_value, region_value);
%
% From scratch to create 2 stations pluviometer associated arrays:
%
% see demo 2
%
% SEE ALSO
% ========
%
% :ref:`guide data station pluviometer <data_station_pluviometer>`
%
% :func:`write_station`
% :func:`plot_station`
%
% TODO
% ====
%
% description du rsultat en ReST
%
% add test
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL: svn+ssh://pinsard@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/simul_station.m $
%
% - fplod 20110816T073113Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * replace int8 by uint8 for integer parameters
%
% - fplod 20110224T100558Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * move part of examples to demo (and fix !)
%
% - fplod 20110221T113719Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add simulation #2 for more realistic names
%
% - fplod 20110218T100837Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * init station_value and region_value to NaN
%
% - fplod 20110217T135637Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * fix init station_value for both matlab and octave
%
% - fplod 20110217T121824Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * usage of cells array of string to handle station_value and code_value
%     strings array are real nightmare (dealing with indices)
%
% - fplod 20110216T091038Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add code
%
% - fplod 20110215T154358Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * creation
%
%-
%
global application;
global application_version;
%
result=-1;
%
usage='lon_value, lat_value, altitude_value, code_value, station_value, region_value]=simul_station(index_simulation)';
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage)
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
arg_info=whos('index_simulation');
if ~strcmp(arg_info.class,'uint8')
   disp(['Incorrect type of arg index_simulation ' arg_info.class]);
   whos index_simulation
   error(usage);
end
clear arg_info
%
% dfinition de la zone gographique
if (index_simulation == 1)
   nb_station=10;
elseif (index_simulation == 2)
   nb_station=3;
else
   error(['eee : unknow simulation ' num2str(index_simulation)]);
end
%
code_value=zeros(nb_station,1,'double');
code_value(:)=NaN;
lon_value=zeros(nb_station,1,'double');
lon_value(:)=NaN;
lat_value=zeros(nb_station,1,'double');
lat_value(:)=NaN;
altitude_value=zeros(nb_station,1,'double');
altitude_value(:)=NaN;
station_value=repmat({'NaN'},nb_station,1);
region_value=repmat({'NaN'},nb_station,1);

if (index_simulation == 1)
   for index_station=1:nb_station
       code_value(index_station)=index_station;
       lon_value(index_station)=-20 + index_station;
       lat_value(index_station)=10.+ index_station;
       altitude_value(index_station)=index_station;
       %
       switch application
          case {'matlab'}
             station_value(index_station)=strcat('station',cellstr(num2str(index_station,'%2.2d')));
          case {'octave'}
             station_value(index_station)=['station',num2str(index_station,'%2.2d')];
          otherwise
             error('unknown application running');
       end
       region_value(index_station)={'ferlo'};
   end
elseif (index_simulation == 2)
     station_value(1)={'barkedji'};
     lon_value(1)=-14.87;
     lat_value(1)=15.28;
     altitude_value(1)=NaN;
     station_value(2)={'barkedji'};
     lon_value(2)=-14.87;
     lat_value(2)=15.28;
     station_value(3)={'LINGUERE'};
     lon_value(3)=-20;
     lat_value(3)=+16;
else
   error(['eee : unknown simulation ' num2str(index_simulation)]);
end
%
clear index_station
clear nb_station
%
%whos
%
result=0;
%
end

%!demo
%! % From scratch to create 10 stations pluviometer associated arrays::
%
%! varamma_startup
%! more off
%! index_simulation = uint8(1);
%! [lon_value, lat_value, altitude_value, code_value, station_value, region_value] = simul_station(index_simulation)

%!demo
%! % From scratch to create 2 stations pluviometer associated arrays::
%
%! varamma_startup
%! more off
%! index_simulation = uint8(2);
%! [lon_value, lat_value, altitude_value, code_value, station_value, region_value] = simul_station(index_simulation)
