function [west_value, east_value, north_value, south_value, zi_code, zi_description]=simul_zi(index_simulation)

%SIMUL_ZI fill zone of interest associated arrays lat, lon, code and description with
%hard coded data

%
%+
%
% ==========
% simul_zi.m
% ==========
%
% .. function:: simul_zi(index_simulation)
%
% DESCRIPTION
% ===========
%
%    :param index_simulation: 1
%    :type index_simulation: uint8
%    :raise index_simulation: required
%
% Charge en mmoire un tableau 2D simul **zi** de prcipitation dans :
%
% Simulation #1
%   3 zones of interest named ``zone``\ xx
%
% EXAMPLES
% ========
%
% From scratch to create 2 zones of interest associated arrays:
%
% see demo 1
%
% To write these arrays in
% :file:`${PROJECT_OD}/maps/varamma_zi_write_zi.csv`::
%
%  see :func:`write_zi`
%
% To plot the zones of interest on a map grid:
%
%  see :func:`plot_zi`
%
% SEE ALSO
% ========
%
% :ref:`zones`
%
% :func:`write_zi`
% :func:`plot_zi`
%
% TODO
% ====
%
% description du rsultat en ReST
%
% add test
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL: svn+ssh://pinsard@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/simul_zi.m $
%
% - fplod 20110816T073113Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * replace int8 by uint8 for integer parameters
%
% - fplod 20110629T085450Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * creation
%
%-
%
global application;
global application_version;
%
result=-1;
%
usage='west_value, east_value, north_value, south_value, zi_code, zi_description]=simul_zi(index_simulation)';
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage)
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
arg_info=whos('index_simulation');
if ~strcmp(arg_info.class,'uint8')
   disp(['Incorrect type of arg index_simulation ' arg_info.class]);
   whos index_simulation
   error(usage);
end
clear arg_info
%
%
% dfinition de la zone gographique
if (index_simulation == 1)
   nb_zi=3;
else
   error(['eee : unknow simulation ' num2str(index_simulation)]);
end
%
west_value=zeros(nb_zi,1,'double');
east_value=zeros(nb_zi,1,'double');
west_value(:)=NaN;
east_value(:)=NaN;
north_value=zeros(nb_zi,1,'double');
north_value(:)=NaN;
south_value=zeros(nb_zi,1,'double');
south_value(:)=NaN;
zi_description=repmat({'NaN'},nb_zi,1);
zi_code=repmat({'NaN'},nb_zi,1);

if (index_simulation == 1)
   for index_zi=1:nb_zi
       west_value(index_zi)=-20 + index_zi;
       east_value(index_zi)=-15 + index_zi;
       north_value(index_zi)=10.+ index_zi;
       south_value(index_zi)=8.+ index_zi;
       %
       switch application
          case {'matlab'}
             zi_description(index_zi)=strcat('zone ',cellstr(num2str(index_zi,'%2.2d')));
             zi_code(index_zi)=strcat('zone',cellstr(num2str(index_zi,'%2.2d')));
          case {'octave'}
             zi_description(index_zi)=['zone ',num2str(index_zi,' %2.2d')];
             zi_code(index_zi)=['zone',num2str(index_zi,'%2.2d')];
          otherwise
             error('unknown application running');
       end
   end
else
   error(['eee : unknown simulation ' num2str(index_simulation)]);
end
%
clear index_zi
clear nb_zi
%
%whos
%
result=0;
%
end

%!demo
%! % From scratch to create 3 zones of interest associated arrays::
%
%! varamma_startup
%! more off
%! index_simulation = uint8(1);
%! [west_value, east_value, north_value, south_value, zi_code, zi_description] = simul_zi(index_simulation)
