;+
;
; .. _ssmi_fastex.pro:
;
; ===============
; ssmi_fastex.pro
; ===============
;
; DESCRIPTION
; ===========
;
;Programme de visualisation ou impression poscript des
;images SSMI de FASTEX (7 canaux) et des parametres
;geophysiques restitues (WV, LW, US) selon les derniers
;algorithmes. Juin 1997.
;
; Projection des images format WENTZ en lat/lon
; sur une grille 40-55N - 30-45W, pas de 0.4
; pour eviter trous dans l'image projetee
; (=> recouvrements de pixels par endroits => moyennes)
;
; TODO
; ====
;
; get inspired to plot amsu data
;
; EVOLUTIONS
; ==========
;
; $Id$
;
; $URL$
;
; - fplod 20111130T121648Z cratos (Linux)
;
;   * minimal rest header
;
;-
;dlon=0.4 & dlat=0.4 ;!version CG
dlon=0.25 & dlat=0.25 ;!version LE 0198
maxlat=fix((55.-40.)/dlat+1.)
maxlon=fix((-30.+45.)/dlon+1.)
print,'Dimension image ',maxlon,maxlat

;******************************************************
; Choix du device: ecran ou papier
; Parametres de position de l'image dans la fenetre
;******************************************************
rep=' '
loadct,0
print,'device x  ou ps ?'
read,rep
numdev=1
if rep eq'ps' then numdev=2

device=rep
set_plot,device
x=[0.,1600.]
y=[1600.,0.]
ypage=29.
xpage=21.

;*****************************************************
; Chargement de la palette de couleurs
; Definition de la legende (11 valeurs)
;*****************************************************
color_trait=0
if rep eq 'x' then color_trait=255
couleur=5	;palette bleu - rouge - jaune
;couleur=2	;palette vert - rouge - bleu
imcol=bytarr(11)
;couleurs associees aux classes
 vmin=1. & vmax=254.
 imcol=[1,26,52,77,102,127,153,178,203,229,254] ;palette 5
;imcol=[1,8,16,30,50,63,80,110,150,180,230]
loadct,couleur


;****************************************************
; Lecture automatique des fichiers para satellite
; (F10, F11 ou F13)
;****************************************************
sat=''
print,'Satellite (10,11,13) ? '
read,sat
rep1=''
name=''
dir='/data_obt2/SSMI/F'+sat+'/'
openr,2,dir+'pro01.lst'
deb:
while (not eof(2)) do begin
lec:
readf,2,name
print,'on traite le fichier?',name
read,rep1
if rep1 eq 'oui' then begin

openr,1,dir+name

;****************************************************
; Declaration des tableaux
;****************************************************
lat=fltarr(64,200)
lon=fltarr(64,200)
tb19v=fltarr(64,200)
tb19h=fltarr(64,200)
tb22v=fltarr(64,200)
tb37v=fltarr(64,200)
tb37h=fltarr(64,200)
tb85v=fltarr(64,200)
tb85h=fltarr(64,200)
val=fltarr(64,200)

tab=fltarr(64)

;*******************************************************
; Lecture des fichiers (64 colonnes, l lignes (variable)
;*******************************************************
on_ioerror,fin
l=0
while (not eof(1)) do begin
;for l=0,78 do begin
readu,1,tab
lat(*,l)=tab
readu,1,tab
lon(*,l)=tab-360.
readu,1,tab
tb19v(*,l)=tab
readu,1,tab
tb19h(*,l)=tab
readu,1,tab
tb22v(*,l)=tab
readu,1,tab
tb37v(*,l)=tab
readu,1,tab
tb37h(*,l)=tab
readu,1,tab
tb85v(*,l)=tab
readu,1,tab
tb85h(*,l)=tab
l=l+1
endwhile
;endfor
close,1
print,'Fichier ',name,l,' lignes'

;**************************************************
; Premier nettoyage: si moins de 20 lignes dans
; l'image, eliminer l'image, sinon traitement
;**************************************************
ll=l
if ll lt 20 then goto,lec
lat=lat(*,0:ll-1)
lon=lon(*,0:ll-1)

;******************************************************
; Affichage des coordonnees des 4 extremites de l'image
;******************************************************
print,'Coordonnees des 4 coins'
print,'1 ',lat(0,0),lon(0,0)
print,'2 ',lat(63,0),lon(63,0)
print,'3 ',lat(63,l-1),lon(63,l-1)
print,'4 ',lat(0,l-1),lon(0,l-1)


;*****************************************************
; Restitution des parametres geophysiques (WV, WL, US)
;*****************************************************
ialgo=1
;algo Goorberlet (vent):
us =1.0969*tb19V -0.4555*tb22V  $
	-1.76*tb37V +0.786*tb37H +147.9	;m/s
;choix des algo: vapeur d'eau
;correction des Tbs optimisee pour algo Guillou
if (ialgo le 2) then begin
tb19V =tb19V -0.5
tb19H =tb19H +0.5
;tb22V =tb22V +0.4
tb37V =tb37V +3.0
tb37H =tb37H +1.
tb85V =tb85V -1.8
tb85H =tb85H -9.1
endif

;algo C. Guillou, 1997
if ialgo eq 1 then wv=18.0824-0.9412*alog(280.-tb19V)- $
1.9768*alog(280.-tb19H )-2.7443*alog(280.-tb22V )-0.0819*alog(280.-tb37V ) $
+2.3437*alog(280.-tb37H )+0.2557*alog(280.-tb85V )-0.5965*alog(280.-tb85H )
; en g/cm2

;algo E. Gerard,1996
if ialgo eq 2 then wv=23.6552-1.4419*alog(280.-tb19V)- $
2.4667*alog(280.-tb19H)-2.6995*alog(280.-tb22V )-0.8057*alog(280.-tb37V) $
+2.4339*alog(280.-tb37H)

; Algorithme d'Alishouse
if ialgo eq 3 then begin
wv=(232.894-0.1486*tb19V-1.8291*tb22V+0.006193*tb22V*tb22V-0.3695*tb37V)*0.1
 ; en g/cm**2
endif

;Algos d'eau liquide
;algo C. Guillou, 1997
if ialgo eq 1 then wl=(72.8184+2.7576*alog(280.-tb19V)+114.3113*alog(280.-tb19H) $
 +8.3059*alog(280.-tb22V)-40.2263*alog(280.-tb37V) $
-106.3735*alog(280.-tb37H)+1.8342*alog(280.-tb85V)-3.4737*alog(280.-tb85H))/100.
; en kg/m2

;***************************************************
;extraction des nuages
;***************************************************
nuag=intarr(64,200)
nu=0
for j=0,ll-1 do begin
 ;for j=0,4 do begin
for i=0,63 do begin
 ;for i=0,10 do begin
if((tb22v(i,j) ne 0.) and (wl(i,j) gt 0.05)) then begin
   nuage=nuag(0>(i-1):(i+1)<63,0>(j-1):j)
   ind=where(nuage gt 0,nb)
      if(nb eq 0) then begin
	nu=nu+1
 	nuag(i,j)=nu
     endif
     if (nb ne 0) then begin
	nuag(i,j)=min(nuage(ind))
	 for kj=0>(j-1),j do begin
	 for ki=0>(i-1),(i+1)<63 do begin
	  if(nuag(ki,kj) ne 0) then nuag(ki,kj)=nuag(i,j)
	 endfor
	 endfor
     endif
endif
endfor
endfor

;on a numerote les nuages. Recherche des affectations abusives
for j=0,ll-1 do begin
for i=0,63 do begin
if(nuag(i,j) gt 0) then begin
  nu=nuag(i,j)
  cloud=nuag(0>(i-1):(i+1)<63,0>(j-1):(j+1)<(ll-1))
  kid=where(cloud eq nu,nbi)
  kdi=where((cloud ne nu) and (cloud ne 0),nbd)
  if nbd gt nbi then nuag(i,j)=min(cloud(kdi))
endif
endfor
endfor
for ik=0,63 do begin
i=63-ik
 for jk=0,ll-1 do begin
j=ll-1-jk
if(nuag(i,j) gt 0) then begin
  nu=nuag(i,j)
  cloud=nuag(0>(i-1):(i+1)<63,0>(j-1):(j+1)<(ll-1))
  kid=where(cloud eq nu,nbi)
  kdi=where((cloud ne nu) and (cloud ne 0),nbd)
  if nbd gt nbi then nuag(i,j)=min(cloud(kdi))
endif
endfor
endfor


;***************************************************
; Visualisation des images
;***************************************************

;*****************************************************
; Choix des parametre a tracer (TB et param geophys)
;*****************************************************
;print,'Choix du parametre ?'
;print,'  tb19v (1)  tb19h (2)  tb22v (3) '
;print,'  tb37v (4)  tb37h (5)'
;print,'  tb85v (6)  tb85h (7)'
;print,'  WL    (8)  WV    (9)  US    (10)'
;print,''
;read,ipar
!p.multi=[0,2,2]
if rep eq 'x' then window,0,xsize=500,ysize=500, title='FASTEX-SSMI'

if rep eq 'ps' then begin

ficps='ssmi.ps'
device,filename=ficps,xsize=xpage,xoffset=0.,yoffset=0., $
	ysize=ypage,/color,bits_per_Pixel=8
endif

xpage=21.
ypage=29.
xcm=10.*0.8
ycm=10.*0.8
xoffset=1.
yoffset=20.
x0=0.5
y0=13.5

for ipar=7,8 do begin
if ipar eq 1 then val= tb19v(*,0:ll-1)
if ipar eq 2 then val= tb19h(*,0:ll-1)
if ipar eq 3 then val= tb22v(*,0:ll-1)
if ipar eq 4 then val= tb37v(*,0:ll-1)
if ipar eq 5 then val= tb37h(*,0:ll-1)
if ipar eq 6 then val= tb85h(*,0:ll-1)
;if ipar eq 7 then val= tb85v(*,0:ll-1)
if ipar eq 7 then val= nuag(*,0:ll-1)
if ipar eq 8 then val= wl(*,0:ll-1)
if ipar eq 9 then val= wv(*,0:ll-1)
if ipar eq 10 then val= us(*,0:ll-1)
if ipar eq 1 then al= 'tb19v'
if ipar eq 2 then al= 'tb19h'
if ipar eq 3 then al= 'tb22v'
if ipar eq 4 then al= 'tb37v'
if ipar eq 5 then al= 'tb37h'
if ipar eq 6 then al= 'tb85h'
;if ipar eq 7 then al= 'tb85v'
if ipar eq 7 then al= 'clouds'
if ipar eq 8 then al= 'wl'
if ipar eq 9 then al= 'wv'
if ipar eq 10 then al='us'

if ipar eq 8 then xoffset=11.
if ipar eq 9 then x0=5.
if ipar ge 9 then y0=12.5
if ipar eq 9 then yoffset=3.
if ipar eq 10 then xoffset=1.
; Titre de la fenetre
;********************
vue='FASTEX '+name +'  '+al
;print,vue

; Declarations - Initialisations
;*******************************
;image=fltarr(maxlon,maxlat) & npt=intarr(maxlon,maxlat)
;image(*,*)=0.
;npt(*,*)=0.

; Projection image en lon,lat
;****************************
;for i=0,ll-1 do begin
;for j=0,63 do begin
;k=fix((lon(j,i)+45.)/dlon+0.5)
;l=fix((lat(j,i)-40.)/dlat+0.5)
;if k ge 0 and k lt maxlon then begin
;if l ge 0 and l lt maxlat then begin
;image(k,l)= image(k,l)+ val(j,i)
;npt(k,l)= npt(k,l)+1
;endif
;endif
;endfor
;endfor

;Choix de la maniere de boucher les trous : 0:non;1:moyennes;2:cressmann
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
parmoy=0
if parmoy ne 0 then begin
if parmoy ne 2 then begin
; Calcul des trous et des recouvrements (donc des moyennes)
;**********************************************************
;ind=where(npt gt 1) & print,'Moyennes=',size(ind)
ind=where(npt eq 0)
mq=size(ind)
;print,'trous   =',mq(1)
if mq(1) eq maxlon*maxlat then goto,lec
npt(where(npt eq 0))=1
image=image/float(npt)

;print,'image  sz=',sz
endif
endif
image=val
sz=size(image)

minps=min(image(where(image gt 0.)))
if ipar eq 7 then minps=0
image(where(image le 0.))=minps
;minps=0.
 maxps=max(image)
print,'min=',minps,'  max=',maxps
;minps=177. & maxps=250.

vue='FASTEX '+name +'  '+al
aps=(vmax-vmin)/(maxps-minps)
image=aps*(image-minps)+vmin
 legende,xpage,ypage,xoffset+x0,y0,imcol, $
	minps,vmin,aps,numdev,ipar
x=indgen(64)
y=indgen(ll)
;x=[-45.,-30.] & y=[40.,55.]
plot,x,y,/nodata,/noerase,color=color_trait,/normal,  $
	;xrange=[-45.,-30.] , yrange=[40.,55.],  $
 	charsize=0.8,xstyle=1,ystyle=1, $
	position=[xoffset/xpage,(yoffset)/ypage, $
	(xoffset+xcm)/xpage,(yoffset+ycm)/ypage]

px=!x.window * !d.x_vsize
py=!y.window * !d.y_vsize
sx=px(1)-px(0)+1
sy=py(1)-py(0)+1

if rep eq 'x' then $
tv,poly_2d(image,[[0,0],[sz(1)/sx,0]],[[0,sz(2)/sy],[0,0]], $
   0,sx,sy), px(0),py(0)


if rep eq 'ps' then $
tv,image,px(0),py(0),xsize=sx,ysize=sy
plot,x,y,/nodata,/noerase,color=color_trait,/normal,  $
	;xrange=[-45.,-30.] , yrange=[40.,55.],  $
 	charsize=0.8,xstyle=1,ystyle=1,title=vue, $
	position=[xoffset/xpage,(yoffset)/ypage, $
	(xoffset+xcm)/xpage,(yoffset+ycm)/ypage]

;spawn,'rm ssmi.ps'

endfor  ; boucle parametre
if rep eq 'ps' then begin

device,/close
 if couleur eq 0 then spawn,'lpr -Pvlpro325 ssmi.ps' else $
     spawn,'lpr -Pvphas326 ssmi.ps'
endif
;print,''
print,'on continue?'
;car=fix(0)
read,rep1
if rep1 eq 'non' then goto,fin
endif
endwhile
fin:
close,2
end

;********************************************************
; Routines Box et Legende
;********************************************************

;********************************************************
; Procedure de remplissage
;********************************************************
 Pro Box, x0, y0, x1, y1, col
 polyfill, [x0,x0,x1,x1], [y0,y1,y1,y0], color=col,/normal
 return
 end

;**********************************
;Procedure de trace de la legende
;**********************************
Pro Legende,xpage,ypage,xo,yo,imcol,minps,vmin,aps,numdev,ipar

if numdev eq 1 then begin
    color_trait=255
endif else begin
    color_trait=0
endelse

;Classes et couleurs
;*******************
 nbclasses=11 ;

;Echelles et couleurs: la legende
;********************************
x0=xo/xpage & y0=yo/ypage
dx=0.6/xpage
dy=0.5/ypage
x1=x0+dx & y1=y0+nbclasses*dy
x=fltarr(nbclasses)
y=fltarr(nbclasses)
 For i=0,nbclasses-1 do begin
    x(i)=x0
    y(i)=i
 Endfor
yy=y0
 For i=0,nbclasses-1 do begin
     box,x0,yy,x1,yy+dy, imcol(i)
    plots,[x0,x1],[yy,yy],color=color_trait,/normal
      classe=((imcol(i)-vmin)/aps+minps)
    if ipar le 7 then tclasse=string(fix(classe),format='(i3)')
    if ipar eq 8 then tclasse=string(classe,format='(f7.1," mg/cm2")')
    if ipar eq 9 then tclasse=string(classe,format='(f7.2," g/cm2")')
    if ipar eq 10 then tclasse=string(classe,format='(f7.2," m/s")')

xyouts,x1,yy+dy/2.,alignment=0.,charsize=0.8,/normal,tclasse
;   print,imcol(i),tclasse
    yy=yy+dy
 Endfor


 plots,[x0,x1],[yy,yy],color=color_trait,/normal
 plots,[x1,x1],[y0,y1],thick=0.5,color=color_trait,/normal
 plots,[x0,x1],[y0,y0],thick=0.5,color=color_trait,/normal
 plots,[x0,x1],[y1,y1],thick=0.5,color=color_trait,/normal
 plots,[x0,x0],[y0,y1],thick=0.5,color=color_trait,/normal
return
end
