#! /bin/sh
#+
#
# .. program:: traite_amsuab.sh
#
# .. _traite_amsuab.sh:
#
# ================
# traite_amsuab.sh
# ================
#
# SYNOPSIS
# ========
#
# ::
#
#  $ traite_amsuab.sh -b yyyymmdd -e yyyymmdd -lonmin lonmin -lonmax lonmax -latmin latmin -latmax latmax -numch numch
#
# DESCRIPTION
# ===========
#
# +todo+
#
# .. option:: -b beginning date <yyyymmdd>
# .. option:: -e end date <yyyymmdd>
# .. option:: -lonmin <lonmin>
# .. option:: -lonmax <lonmax>
# .. option:: -latmin <latmin>
# .. option:: -latmax <latmax>
# .. option:: -numch <channel>
#
# ``traite_amsuab.sh`` read :file:`${PROJECT_ID}/AMSU/AMSU*/*/*.L1C``
# and :file:`${PROJECT}/SRC/dataref_amsu/COR*.dat`
#
# Some IDL programs are launched here using ${IDL_CMD} command
# (see :ref:`varamma_profile.sh` to know how to set this environnement variable).
#
# +todo+
#
# Log file is written on
# :file:`${PROJECT_LOG}/traite_amsuab.log.{YYYYMMDDTHHMMSSZ}`
#
# .. only:: man
#
#    Figure is visible on PDF and HTML documents only.
#
# .. only:: html or latex
#
#     .. graphviz::
#
#        digraph traite_amsuab {
#
#           amsu_t1 [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/AMSU/AMSU*/L1C/yyyy/yyyy_mm_dd/*.L1C"];
#           amsu_a_cor_land [shape=diamond,fontname=Courier,label="${PROJECT}/src/dataref_amsu/CORR_LAND_AMSUA5_DataFromJune2010_40deg.DAT"];
#           amsu_a_cor_sea [shape=diamond,fontname=Courier,label="${PROJECT}/src/dataref_amsu/CORR_SEA_AMSUA5_DataFromJune2010_40deg.DA"];
#           amsu_t2 [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/yyyy/mm/amsua_amsub_yyyymmdd_geomin_geomax.dat"];
#           amsu_t3 [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/yyyy/mm/amsua_amsub_yyyymmdd_geomin_geomax_nadir.dat"];
#           amsu_t4 [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/yyyy/mm/amsua_amsub_yyyymmdd_geomin_geomax_nadir.nc"];
#           mask [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/MASK/ETOPO1_Ice_g_gmt4.nc"];
#
#           log [shape=ellipse,fontname=Courier,label="${PROJECT_LOG}/traite_amsuab.log{YYYYMMDDTHHMMSSZ}"];
#
#           traite_amsuab [shape=box,
#           fontname=Courier,
#           color=blue,
#           URL="http://forge.ipsl.jussieu.fr/varamma/browser/trunk/src/traite_amsuab.sh",
#           label="${PROJECT}/src/traite_amsuab.sh"];
#
#           {amsu_t1 amsu_a_cor_land amsu_a_cor_sea mask} -> {traite_amsuab} -> {log amsu_t2 amsu_t3 amsu_t4}
#
#         }
#
# EXAMPLES
# ========
#
# You already used :ref:`get_amsu.sh` to get AMSU data including channel a5
# during [20060801, 20060802[ and you want to produce NetCDF files::
#
#   traite_amsuab.sh -b 20060801 -e 20060802 -lonmin -25 -lonmax 25 -latmin -5 -latmax 20 -numch a5
#
# And look at log file with ::
#
#   tlogd.sh traite_amsuab
#
# A more realistic example::
#
#   traite_amsuab.sh -b 20060101 -e 20060630 -lonmin -32 -lonmax 32 -latmin -2 -latmax 42
#
# and of course on files in ${PROJECT_ID}.
#
# If you want to work on channel b5 of AMSU::
#
#   traite_amsuab.sh -b 20060813 -e 20060814 -lonmin -25 -lonmax 25 -latmin -5 -latmax 20 -numch b5
#
# SEE ALSO
# ========
#
# IDL_
#
# .. _IDL: http://www.ittvis.com/ProductServices/IDL.aspx
#
# :ref:`varamma_profile.sh`
# :ref:`project_init.pro`
#
# :ref:`run_traite_amsuab.sh` to submit job
#
# Previous step : :ref:`get_amsu.sh`
#
# Use :
# :ref:`extract_amsua.pro`
# :ref:`amsu2ncdf.pro`
# :func:`search_amsufiles`
#
# :ref:`geolocation_to_string_sh.sh`
#
# .. todo::
#
# TODO
# ====
#
# usage of profile on parameter true only
#
# get all procedure in profiler report (pb of sequence between
# compile statements and call to profiler ?)
#
# se bloque sur
# /homedata/pinsard/varamma_d/AMSU/AMSUBN17/L1C/2006/2006_08_01/NSS.AMBX.NM.D06213.S1029.E1224.B2132223.WI.L1C
# avec use_amsua 0
#
# why need .compile ?!
#
# build/complete catalog
#
# adjust yyyymmddb_min and yyyymmdde_max
#
# idl status = 0 even if not ok
#
# handle -f option
#
# test if demo mode idl (or force cancel if demo)
#
# what about
# lire_amsuab_new.pro:if (ambfile eq '/bdd/AMSU-1C/AMSUBN15/L1C/2006/2006_03_14/NSS.AMBX.NK.D06073.S1701.E1846.B4072728.GC.L1C') then goto,labett ;exception fichier erronne
# lire_amsuab_new.pro:if (ambfile eq '/bdd/AMSU-1C/AMSUBN15/L1C/2004/2004_06_25/NSS.AMBX.NK.D04177.S1824.E1950.B3180102.WI.L1C') then goto,labett ;exception fichier erronne
#
# EVOLUTIONS
# ==========
#
# $Id$
#
# $URL$
#
# - pinsard 20120529T150524Z loholt1.ipsl.polytechnique.fr (Linux)
#
#   * bug fix to handle correctly dates if translation in second on 9 digits
#     (trailing 0 is automaticaly interpreted as an octal number).
#     ex = 20010801
#   * bug fix to handle correctly dates if translation in second of begin
#     and end is not on the same number of digit
#     ex : -b 20010801 -e 20010931
#
# - fplod 20120420
#
#   * add some compile to complete profiler report
#   * add a realistic example from laurence
#
# - fplod 20120419
#
#   * add test on files_list
#   * new technique to validate yyyymmdd
#     because ::
#
#        yyyymmddb=200601010
#        ${date_cmd} -d "${yyyymmddb}"
#        Sun Oct 10 00:00:00 CET 20060
#
#     alors qu'on avait pu supposer que cela renvoie "date invalid" (anne sur 5 digits !)
#
# - fplod 20120417
#
#   * add some Profiler usage thanks to
#     http://www.idlcoyote.com/code_tips/whyslow.html
#
# - pinsard 20120416
#
#   * update min max yyyymmdd
#
# - pinsard 20120323
#
#   * replace creation of :file:`${PROJECT_ID}/list_file` by a call to
#     :func:`search_amsufiles`
#   * transform the IDL snippet to a function to be abble to use ``CASE``
#
# - pinsard 20120106
#
#   * update header (no more use_amsu, correction files under src/dataref_amsu)
#   * remplace VARAMMA by PROJECT
#   * test if at least one file to be read
#   * ajout pour connaitre la dure du traitement de chaque jour
#   * add ref to :ref:`run_traite_amsuab.sh`
#
# - pinsard 2011-08-22T14:32:21Z loholt1.ipsl.polytechnique.fr (Linux)
#
#   * usage of ${IDL_CMD} instead of idl to allow run on idl 6.4 (/opt/idl-6.4/idl/bin/idl on climserv)
#
# - fplod 20110818T154338Z cratos (Linux)
#
#   * test on cratos after copying files from climserv
#
#     as get_amsu.sh do not yet work on cratos copies have been done using
#     this kind of sequence
#     ::
#
#      cratos$ mkdir -p ${PROJECT_ID}/AMSU/AMSUBN17/L1C/2006/
#      loholt1$ scp -r /bdd/AMSU-1C/AMSUBN17/L1C/2006/2006_08_01 fplod@cerbere.locean-ipsl.upmc.fr:/usr/work/incas/fplod/varamma_d/AMSU/AMSUBN17/L1C/2006/
#
# - pinsard 2011-08-18T10:23:42Z loholt1.ipsl.polytechnique.fr (Linux)
#
#   * reach end with amsu-b only on loholt1
#
# - pinsard 2011-08-18T07:37:43Z loholt1.ipsl.polytechnique.fr (Linux)
#
#   * use geolocation_to_string_sh to build geobox
#
# - pinsard 2011-08-10T15:36:50Z loholt1.ipsl.polytechnique.fr (Linux)
#
#   * update amsu2ncdf call
#
# - fplod 20110810T081339Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * correct_nadir_LE06 has been replaced by correct_nadir_amsu.
#   * correction of graph
#
# - lelod/fplod 20110809
#
#   * new idl tools : need a list of file and new parameters
#
# - fplod 20110531T085708Z cratos.locean-ipsl.upmc.fr (Linux)
#
#   * remove "_" in parameter variables
#
# - pinsard 2011-05-30T14:32:02Z loholt1.ipsl.polytechnique.fr (Linux)
#
#   * produce daily files
#   * complete graphic
#
# - pinsard 2011-05-26T10:57:48Z loholt1.ipsl.polytechnique.fr
#
#   * add lonmin,lonmax,latmin,latmax parameters
#   * create a temporary file for idl command
#   * amsu2ncdf should work now on one day
#
# - pinsard 2011-05-26T10:37:42Z loholt1.ipsl.polytechnique.fr
#
#   * correct_nadir_LE06 work now on one day
#   * add mask in doc
#
# - pinsard 2011-05-25T13:16:37Z loholt1.ipsl.polytechnique.fr (Linux)
#
#   * get rid of yr and jm
#
# - fplod 20110511T102251Z cratos.locean-ipsl.upmc.fr (Linux)
#
#   * add -a parameter to handle use_amsua and use_amsub parameters of IDL
#     program
#
# - pinsard 2011-05-05T07:11:18Z loholt1.ipsl.polytechnique.fr (Linux)
#
#   * consolidation
#     nb : tricky string to integer pb. see http://www.mail-archive.com/bug-bash@gnu.org/msg06358.html
#
# - fplod 20110426T090939Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * usage of PROJECT*
#
# - fplod 20100608T143812Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * minimal header
#-
system=$(uname)
case "${system}" in
   AIX|IRIX64)
     echo "${command} : www : no specific posix checking"
     date_cmd=date
   ;;
   Darwin)
     set -o posix
     date_cmd=gdate
   ;;
   Linux)
     set -o posix
     date_cmd=date
   ;;
   *)
    set -o posix
   ;;
esac
unset system
#
set -u
#
LANG=POSIX
#
command=$(basename ${0})
log_date=$(date -u +"%Y%m%dT%H%M%SZ")
#
usage=" Usage : ${command} [-f] -b yyyymmdd -e yyyymmdd -lonmin lonmin -lonmax lonmax -latmin latmin -latmax latmax -numch numch"
#
hostname=$(hostname)
#
yyyymmddb_min=20000101
yyyymmdde_max=20121231
#
# default
debug=0
force=0
yyyymmddb=20060420
yyyymmdde=20060420
numch='a5'
jdeb=1
jfin=10
netcdf_build=0
#
minargcount=4
if [ ${#} -lt ${minargcount} ]
then
   echo "${command} : eee : not enought arguments"
   echo "${usage}"
   exit 1
fi
unset minargcount
#
while [ ${#} -gt 0 ]
do
   case ${1} in
     -b)
        # first date to get
        yyyymmddb=${2}
        shift
     ;;
     -e)
        # last date to get
        yyyymmdde=${2}
        shift
     ;;
     -lonmin)
        lonmin=${2}
        shift
     ;;
     -lonmax)
        lonmax=${2}
        shift
     ;;
     -latmin)
        latmin=${2}
        shift
     ;;
     -latmax)
        latmax=${2}
        shift
     ;;
     -numch)
        numch=${2}
        shift
     ;;
     -f)
        force=1
     ;;
     -h)
        echo "${usage}"
        exit 0
     ;;
     *)
        # other choice
        echo "${command} : eee : unknown option ${1}"
        echo "${usage}"
        exit 1
     ;;
   esac
   # next flag
   shift
done
unset usage
#
# check parameters
# and define associated variables
${date_cmd} -d "${yyyymmddb}" > /dev/null
status_date=${?}
if [ ${status_date} -ne 0 ]
then
    echo "${command} : eee : yyyymmddb ${yyyymmddb} argument invalid"
    exit 1
fi
unset status_date
#
d=$((${yyyymmddb} - ${yyyymmddb_min}))
if [ ${d} -lt 0 ]
then
    echo "${command} : eee : yyyymmddb ${yyyymmddb} must be equal or greater than yyyymmddb_min ${yyyymmddb_min}"
    exit 1
fi
#
d=$((${yyyymmddb} - ${yyyymmdde_max}))
if [ ${d} -gt 0 ]
then
    echo "${command} : eee : yyyymmddb ${yyyymmddb} must be equal or lower than yyyymmdde_max ${yyyymmdde_max}"
    exit 1
fi
#
${date_cmd} -d "${yyyymmdde}" > /dev/null
status_date=${?}
if [ ${status_date} -ne 0 ]
then
    echo "${command} : eee : yyyymmdde ${yyyymmdde} argument invalid"
    exit 1
fi
unset status_date
#
d=$((${yyyymmdde} - ${yyyymmdde_max}))
if [ ${d} -gt 0 ]
then
    echo "${command} : eee : yyyymmdde ${yyyymmdde} must be lower or equal to yyyymmdde_max ${yyyymmdde_max}"
    exit 1
fi
#
if [[ "${yyyymmdde}" < "${yyyymmddb}" ]]
then
    echo "${command} : eee : yyyymmdde ${yyyymmdde} must be greater than yyyymmddb ${yyyymmddb}"
    exit 1
fi
#
if [[ "${yyyymmdde}" = "${yyyymmddb}" ]]
then
     echo "${command} : eee : yyyymmdde ${yyyymmdde} must be greater than yyyymmddb ${yyyymmddb}"
     exit 1
fi
#
tool=${IDL_CMD}
type ${tool} 1> /dev/null 2>&1
status=${?}
if [ ${status} -ne 0 ]
then
   echo "${command} : eee : tool ${IDL_CMD} not found"
   echo "${command} : eee : check varamma_profile.sh sequence"
   exit 1
fi
unset status
unset tool
#
#
tool=ncrcat
type ${tool} 1> /dev/null 2>&1
status=${?}
if [ ${status} -ne 0 ]
then
   echo "${command} : eee : tool ${tool} not found"
   exit 1
fi
unset status
unset tool
#
# check for write permission on PROJECT_LOG
if [ ! -w ${PROJECT_LOG} ]
then
   echo "${command} : eee : ${PROJECT_LOG} not writable"
   exit 1
fi
#
log=${PROJECT_LOG}/$(basename ${0} .sh).log.${log_date}
echo "[Context]" 1>> ${log}
echo "command=$(basename ${0})" 1>>${log}
echo "hostname=${hostname}" 1>> ${log}
echo "runtime=${log_date}" 1>> ${log}
echo "log=${log}" 1>> ${log}
echo "IDL_CMD=${IDL_CMD}" 1>> ${log}
unset log_date
echo "" 1>> ${log}
echo "[Parameters]" 1>> ${log}
echo "yyyymmddb=${yyyymmddb}" 1>> ${log}
echo "yyyymmdde=${yyyymmdde}" 1>> ${log}
echo "lonmin=${lonmin}" 1>> ${log}
echo "lonmax=${lonmax}" 1>> ${log}
echo "latmin=${latmin}" 1>> ${log}
echo "latmax=${latmax}" 1>> ${log}
echo "numch=${numch}"  1>> ${log}
echo "" 1>> ${log}
#
# build geomax from parameters
geomin=$(geolocation_to_string_sh.sh -lon ${lonmin} -lat ${latmin})
status=${?}
if [ ${status} -ne 0 ]
then
   echo "${command} : eee : pb geomin with geolocation_to_string_sh.sh" 1>> ${log}
   exit 1
fi
geomax=$(geolocation_to_string_sh.sh -lon ${lonmax} -lat ${latmax})
status=${?}
if [ ${status} -ne 0 ]
then
   echo "${command} : eee : pb geomax with geolocation_to_string_sh.sh" 1>> ${log}
   exit 1
fi
#
# loop over all dates
# set current and end date
current=$(${date_cmd} -u -d "${yyyymmddb}" +%s | awk '{printf "%d",$1}')
declare -i current
end=$(${date_cmd} -u -d "${yyyymmdde}" +%s | awk '{printf "%d",$1}')
declare -i end
declare -i delta=86400
while [ ${current} -lt ${end} ]
do
    # get current time at the beginning of the process for one day
    timebd="$(date +%s)"
    echo "${command} : iii : looking for files of $(${date_cmd} -u -d "1970-01-01 ${current} sec" +%Y%m%dT%H%M)" 1>> ${log}
    yyyymmdd=$(${date_cmd} -u -d "1970-01-01 ${current} sec" +%Y%m%d)
    yyyy=$(${date_cmd} -u -d "1970-01-01 ${current} sec" +%Y)
    mm=$(${date_cmd} -u -d "1970-01-01 ${current} sec" +%m)
    dd=$(${date_cmd} -u -d "1970-01-01 ${current} sec" +%d)
    hh=$(${date_cmd} -u -d "1970-01-01 ${current} sec" +%H)
    mn=$(${date_cmd} -u -d "1970-01-01 ${current} sec" +%M)
    #
    prefix=$(printf  "%1c" ${numch} | tr [:lower:] [:upper:])

    cat >> ${PROJECT}/src/traite_amsu_${$}.pro << EOF
function traite_amsu_${$}
;
compile_opt idl2, strictarrsubs
;
@cm_project
@common
;
result = -1
;
result = search_amsufiles('${numch}', ${yyyy},${mm}, ${dd})
result_type=size(result,/type)
IF (result_type EQ 3) THEN BEGIN
   IF (result EQ -1) THEN BEGIN
       print, 'eee : pb search_amsufiles'
       return, result
   ENDIF
ENDIF ELSE BEGIN
   files_list = result
ENDELSE
;
result = file_bathy_to_mem(${lonmin}, ${lonmax}, ${latmin}, ${latmax})
IF (result EQ -1) THEN BEGIN
   print, 'eee : pb file_bathy_to_mem'
   return, result
ENDIF
;
; uncomment the following lines to test with the last file of the list
; files_list_new_array = strarr(1)
; files_list_new_array[0] = files_list[N_ELEMENTS(files_list) - 1]
; files_list = files_list_new_array
;
; uncomment the following lines to test with the two last files of the list
; files_list_new_array = strarr(2)
; files_list_new_array[0] = files_list[N_ELEMENTS(files_list) - 2]
; files_list_new_array[1] = files_list[N_ELEMENTS(files_list) - 1]
; files_list = files_list_new_array
;
; uncomment the following lines to test with the first file of the list
; files_list_new_array = strarr(1)
; files_list_new_array[0] = files_list[1]
; files_list = files_list_new_array
;
CASE size(files_list,/DIMENSION) OF
   0L : BEGIN
            print, 'www : no file found'
        END
   ELSE: BEGIN
            print, 'iii : nb de fichiers', size(files_list,/DIMENSION)
            resol=1
            extract_amsua, '${numch}', files_list, ${yyyy}, ${mm}, ${dd}, resol, ${lonmin}, ${lonmax}, ${latmin}, ${latmax}
        END
ENDCASE
EOF
    if [ ${netcdf_build} -eq 1 ]
    then
        cat >> ${PROJECT}/src/traite_amsu_${$}.pro << EOF
amsu2ncdf, ${use_amsua}, ${yyyy},${mm},${dd}, ${lonmin}, ${lonmax}, ${latmin}, ${latmax}
EOF
     fi
     cat >> ${PROJECT}/src/traite_amsu_${$}.pro << EOF
return, result
end
EOF
    ${IDL_CMD} << EOF >> ${log} 2>&1
key_performance = 0
; totally shut down all profiling
profiler,/CLEAR,/SYSTEM & profiler,/CLEAR,/RESET
; add system procedure
Profiler, /SYSTEM
; compile users procedures to be scan by Profiler
.compile interpol_correc
.compile extract_amsua
.compile read_amsua1c
.compile define_amsua_header_struct
.compile define_amsua_struct
.compile pixelsize
.compile mem_to_file_amsu_t2
.compile geolocation_to_string_idl
.compile file_bathy_to_mem
; add users procedures
Profiler
result = traite_amsu_${$}()
print, 'ppp : profiler report begin'
Profiler, /REPORT
print, 'ppp : profiler report end'
EOF
    status=${?}
    if [ ${status} -ne 0 ]
    then
       echo "${command} : eee: ${IDL_CMD} failed : ${status}" >> ${log} 2>&1
       cat ${PROJECT}/src/traite_amsu_${$}.pro >> ${log} 2>&1
       exit 1
    fi
    rm ${PROJECT}/src/traite_amsu_${$}.pro
    unset status
    if [ ${netcdf_build} -eq 1 ]
    then
         # concatenate yyyymmdd-hhmnss NetCDF files
         list=${PROJECT_ID}/AMSU/${yyyy}/${mm}/${prefix}${yyyy}${mm}${dd}_??????_${geomin}_${geomax}_nadir.nc
         fileout=${PROJECT_ID}/AMSU/${yyyy}/${mm}/${prefix}${yyyy}${mm}${dd}_${geomin}_${geomax}_nadir.nc
         ncrcat -O ${list} ${fileout} >> ${log} 2>&1
         status=${?}
         if [ ${status} -ne 0 ]
         then
             echo "${command} : eee : pb with ncrcat" 1>> ${log}
             for file in ${list}
             do
                 ncdump -h ${file} >> ${log} 2>&1
             done
             exit 1
          else
             echo "${command} : iii : adding ${fileout}" >> ${log} 2>&1
          fi
    fi
    unset dd
    # get current time at the end of the process for one day
    timeed="$(date +%s)"
    elapsed_seconds="$(( ${timeed} - ${timebd} ))"
    echo "${command} : iii : Elapsed time for this day (s) : ${elapsed_seconds}" >> ${log} 2>&1
    unset timebd
    unset timeed
    # next time step
    current=$((${current} + ${delta}))
done
#
unset yyyy
unset mm
#
unset command
unset log
unset hostname
unset usage
#
unset date_cmd
#
# end
#++set
exit
